@@ -15,27 +15,29 @@
  *  along with this program; if not, write to the Free Software
  */
 
-#include <qpainter.h>
-#include <qtooltip.h>
-#include <qdrawutil.h>
-#include <qcursor.h>
-#include <qimage.h>
-#include <qpopupmenu.h>
+#include <QtGui/QPainter>
+#include <QtGui/qdrawutil.h>
+#include <QtGui/QCursor>
+#include <QtGui/QImage>
+#include <QtGui/QMouseEvent>
+#include <QtCore/QTimerEvent>
+#include <QtGui/QResizeEvent>
+#include <QtCore/QProcess>
+#include <QtGui/QX11Info>
 
-#include <kaboutapplication.h>
-#include <kpopupmenu.h>
+#include <KMenu>
+#include <kaboutapplicationdialog.h>
 #include <kaboutdata.h>
 #include <klocale.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
+#include <kcolorscheme.h>
 #include <kapplication.h>
 #include <kiconloader.h>
 #include <kiconeffect.h>
-#include <knotifyclient.h>
 #include <kshortcut.h>
-#include <kkeynative.h>
 #include <kdemacros.h>
-#include <kprocess.h>
+#include <ktoolinvocation.h>
 #include "kdeexportfix.h"
 #include "kbstate.h"
 #include "kbstate.moc"
@@ -50,10 +52,10 @@ extern "C"
 #include <X11/keysymdef.h>
 #include <X11/extensions/XKB.h>
 
-    KDE_EXPORT KPanelApplet* init(QWidget *parent, const QString& configFile)
+    KDE_EXPORT K3PanelApplet* init(QWidget *parent, const QString& configFile)
     {
-        KGlobal::locale()->insertCatalogue("kbstateapplet");
-        KbStateApplet *applet = new KbStateApplet(configFile, KPanelApplet::Normal, KPanelApplet::About, parent, "kbstateapplet");
+        KGlobal::locale()->insertCatalog("kbstateapplet");
+        KbStateApplet *applet = new KbStateApplet(configFile, K3PanelApplet::Normal, K3PanelApplet::About, parent, "kbstateapplet");
         return applet;
     }
 }
@@ -85,25 +87,29 @@ static ModifierKey modifierKeys[] = {
 
 /********************************************************************/
 
-KbStateApplet::KbStateApplet(const QString& configFile, Type t, int actions,
+KbStateApplet::KbStateApplet(const QString& configFile, K3PanelApplet::Type t, int actions,
                        QWidget *parent, const char *name)
-  : KPanelApplet( configFile, t, actions, parent, name )
+  : K3PanelApplet( configFile, t, actions, parent ),
+    componentData("kbstateapplet")
 {
+   Q_UNUSED(name)
+
    for (int i = 0; i < 8; i++) {
       icons[i] = 0;
    }
-   instance = new KInstance ("kbstateapplet");
+   m_iconLoader = new KIconLoader(componentData.componentName(), componentData.dirs());
+
    loadConfig();
 	initMasks();
-	mouse    = new MouseIcon (instance, this, "mouse");
-	sticky   = new TimeoutIcon (instance, "", "kbstate_stickykeys", this, "sticky");
-	slow   = new TimeoutIcon (instance, "", "kbstate_slowkeys", this, "slow");
-	bounce = new TimeoutIcon (instance, "", "", this, "bounce");
+	mouse    = new MouseIcon (m_iconLoader, this, "mouse");
+	sticky   = new TimeoutIcon (m_iconLoader, "", "kbstate_stickykeys", this, "sticky");
+	slow   = new TimeoutIcon (m_iconLoader, "", "kbstate_slowkeys", this, "slow");
+	bounce = new TimeoutIcon (m_iconLoader, "", "", this, "bounce");
 
-	xkb = XkbGetMap(qt_xdisplay(), 0, XkbUseCoreKbd);
+	xkb = XkbGetMap(QX11Info::display(), 0, XkbUseCoreKbd);
 
 	if (xkb != 0) {
-		XkbGetControls (qt_xdisplay(), XkbAllControlsMask, xkb);
+		XkbGetControls (QX11Info::display(), XkbAllControlsMask, xkb);
 		if (xkb->ctrls != 0)
 			accessxFeatures = xkb->ctrls->enabled_ctrls;
 		else
@@ -113,12 +119,12 @@ KbStateApplet::KbStateApplet(const QString& configFile, Type t, int actions,
 		accessxFeatures = 0;
 
    //startTimer(100); // ten times a second
-   connect(kapp, SIGNAL(kdisplayPaletteChanged()), SLOT(paletteChanged()));
+   connect(KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()), SLOT(paletteChanged()));
    
    kapp->installX11EventFilter (this);
    int opcode_rtn, error_rtn;
-   XkbQueryExtension (this->x11Display(), &opcode_rtn, &xkb_base_event_type,  &error_rtn, NULL, NULL);
-   XkbSelectEvents (this->x11Display(), XkbUseCoreKbd, XkbAllEventsMask,
+	XkbQueryExtension (QX11Info::display(), &opcode_rtn, &xkb_base_event_type,  &error_rtn, NULL, NULL);
+	XkbSelectEvents (QX11Info::display(), XkbUseCoreKbd, XkbAllEventsMask,
 						  XkbAllEventsMask);
    
 	buildPopupMenu();
@@ -127,39 +133,39 @@ KbStateApplet::KbStateApplet(const QString& configFile, Type t, int actions,
 KbStateApplet::~KbStateApplet() {
    kapp->removeX11EventFilter (this);
    setCustomMenu(0);
-   delete instance;
+   delete m_iconLoader;
    delete popup;
    delete sizePopup;
 }
 // Builds, connects _popup menu
 void KbStateApplet::buildPopupMenu()
 {
-   sizePopup=new KPopupMenu(this);
+   sizePopup=new KMenu(this);
    sizePopup->setCheckable( true );
    sizePopup->insertItem(i18n("Small"),  13);
    sizePopup->insertItem(i18n("Medium"), 20);
    sizePopup->insertItem(i18n("Large"),  26);
    connect(sizePopup,SIGNAL(activated(int)), this, SLOT(setIconDim(int)));
 
-   showPopup=new KPopupMenu(this);
+   showPopup=new KMenu(this);
    showPopup->setCheckable( true );
    modifierItem=showPopup->insertItem(i18n("Modifier Keys"), this, SLOT(toggleModifier()));
 	lockkeysItem=showPopup->insertItem(i18n("Lock Keys"),     this, SLOT(toggleLockkeys()));
 	mouseItem=showPopup->insertItem(i18n("Mouse Status"), this, SLOT(toggleMouse()));
 	accessxItem=showPopup->insertItem(i18n("AccessX Status"), this, SLOT(toggleAccessX()));
 
-	popup = new KPopupMenu(this);
+	popup = new KMenu(this);
 	popup->setCheckable( true );
-   popup->insertTitle(0, i18n("Keyboard Status Applet"));
+   popup->addTitle(i18n("Keyboard Status Applet"));
 	popup->insertItem(i18n("Set Icon Size"),sizePopup);
 	fillSpaceItem = popup->insertItem(i18n("Fill Available Space"),
 												 this, SLOT(toggleFillSpace()));
    popup->insertItem(i18n("Show"),showPopup);
-   popup->insertItem(i18n("Configure AccessX Features..."), this, SLOT(configureAccessX()));
-   popup->insertItem(i18n("Configure Keyboard..."), this, SLOT(configureKeyboard()));
-   popup->insertItem(i18n("Configure Mouse..."), this, SLOT(configureMouse()));
-   popup->insertSeparator();
-   popup->insertItem(i18n("About"), this, SLOT(about()));
+   popup->addAction(i18n("Configure AccessX Features..."), this, SLOT(configureAccessX()));
+   popup->addAction(i18n("Configure Keyboard..."), this, SLOT(configureKeyboard()));
+   popup->addAction(i18n("Configure Mouse..."), this, SLOT(configureMouse()));
+   popup->addSeparator();
+   popup->addAction(i18n("About"), this, SLOT(about()));
    setCustomMenu(popup);
    updateMenu();
 }
@@ -264,7 +270,7 @@ int KbStateApplet::heightForWidth(int w) const {
 }
 
 void KbStateApplet::mousePressEvent(QMouseEvent *e) {
-   if (e->button() == RightButton)
+   if (e->button() == Qt::RightButton)
       popup->popup(e->globalPos());
 }
 
@@ -277,6 +283,11 @@ void KbStateApplet::setIconDim (int size) {
    emit updateLayout();
 }
 
+void KbStateApplet::resizeEvent( QResizeEvent*e ) {
+   QWidget::resizeEvent(e);
+   layout();
+}
+
 void KbStateApplet::toggleFillSpace() {
 	fillSpace = !fillSpace;
 	saveConfig();
@@ -286,13 +297,8 @@ void KbStateApplet::toggleFillSpace() {
 	emit updateLayout();
 }
 
-void KbStateApplet::resizeEvent( QResizeEvent*e ) {
-   QWidget::resizeEvent(e);
-   layout();
-}
-
 void KbStateApplet::layout() {
-	int size = this->size;
+   int size = this->size;
 
    int lines, length, x,y,dx,dy, ldx,ldy;
 	int modifierCount = showModifiers?modifiers.count():0;
@@ -308,7 +314,7 @@ void KbStateApplet::layout() {
 			accessxCount++;
 	}
 
-   if (orientation() == Vertical) {
+   if (orientation() == Qt::Vertical) {
 		calculateSizes (width(), modifierCount, lockkeyCount, accessxCount,
 							 showMouse, lines, length, size);
 		
@@ -526,13 +532,18 @@ void KbStateApplet::initMasks() {
    }
    state = 0;
    
-   for (int i = 0; modifierKeys[i].name; i++) {
+   for (int i = 0; strcmp(modifierKeys[i].name, "") != 0; i++) {
       int mask = modifierKeys[i].mask;
       if (mask == 0)
          if (modifierKeys[i].keysym != 0)
-            mask = XkbKeysymToModifiers (this->x11Display(), modifierKeys[i].keysym);
-         else if (!strcmp(modifierKeys[i].name, "Win"))
-            mask = KKeyNative::modX(KKey::WIN);
+      		mask = XkbKeysymToModifiers (this->x11Display(), modifierKeys[i].keysym);
+#ifdef __GNUC__
+#warning "kde4: how to port it ?"	  
+#endif      
+#if 0
+		 else if (strcmp(modifierKeys[i].name, "Win") == 0)
+            mask = KKeyNative::modXWin();
+#endif	  
          else
             mask = XkbKeysymToModifiers (this->x11Display(), XK_Mode_switch)
                  | XkbKeysymToModifiers (this->x11Display(), XK_ISO_Level3_Shift)
@@ -545,8 +556,8 @@ void KbStateApplet::initMasks() {
             break;
       }
       if ((map <= 7) && !(icons[map])) {
-         icons[map] = new KeyIcon (i, instance, this, modifierKeys[i].name);
-         QToolTip::add (icons[map], i18n (modifierKeys[i].name));
+         icons[map] = new KeyIcon (i, m_iconLoader, this, modifierKeys[i].name);
+         icons[map]->setToolTip( i18n (modifierKeys[i].name));
          connect (icons[map], SIGNAL(stateChangeRequest (KeyIcon*,bool,bool)),
                                 SLOT(stateChangeRequest (KeyIcon*,bool,bool)));
          if (modifierKeys[i].isModifier)
@@ -569,7 +580,7 @@ bool KbStateApplet::x11Event (XEvent *evt) {
       case XkbAccessXNotify:
          switch (kbevt->accessx.detail) {
          case XkbAXN_SKPress:
-				slow->setGlyth(i18n("a (the first letter in the alphabet)", "a"));
+				slow->setGlyth(i18nc("a (the first letter in the alphabet)", "a"));
 				slow->setImage("unlatched");
             break;
          case XkbAXN_SKAccept:
@@ -583,11 +594,11 @@ bool KbStateApplet::x11Event (XEvent *evt) {
             slow->setImage("keypressno", kbevt->accessx.sk_delay>150?kbevt->accessx.sk_delay:150);
             break;
 				case XkbAXN_BKAccept:
-					slow->setGlyth(i18n("a (the first letter in the alphabet)", "a"));
+					slow->setGlyth(i18nc("a (the first letter in the alphabet)", "a"));
 					bounce->setImage("keypressok", kbevt->accessx.sk_delay>150?kbevt->accessx.sk_delay:150);
             break;
 				case XkbAXN_BKReject:
-					slow->setGlyth(i18n("a (the first letter in the alphabet)", "a"));
+					slow->setGlyth(i18nc("a (the first letter in the alphabet)", "a"));
 					bounce->setImage("keypressno", kbevt->accessx.sk_delay>150?kbevt->accessx.sk_delay:150);
             break;
          }
@@ -597,7 +608,7 @@ bool KbStateApplet::x11Event (XEvent *evt) {
 				accessxFeatures = event->enabled_ctrls;
 				
 				if ((accessxFeatures & XkbMouseKeysMask) != 0) {
-					XkbGetControls (qt_xdisplay(), XkbMouseKeysMask, xkb);
+					XkbGetControls (QX11Info::display(), XkbMouseKeysMask, xkb);
 					if (xkb->ctrls->mk_dflt_btn < 1)
 						mouse->setActiveKey (1);
 					else if (xkb->ctrls->mk_dflt_btn > 3)
@@ -662,7 +673,6 @@ void KbStateApplet::toggleModifier() {
    updateMenu();
    layout();
    updateGeometry();
-   saveConfig();
    emit updateLayout();
 }
 
@@ -671,7 +681,6 @@ void KbStateApplet::toggleLockkeys() {
    updateMenu();
    layout();
    updateGeometry();
-   saveConfig();
    emit updateLayout();
 }
 
@@ -680,7 +689,6 @@ void KbStateApplet::toggleMouse() {
    updateMenu();
    layout();
    updateGeometry();
-   saveConfig();
    emit updateLayout();
 }
 
@@ -689,67 +697,62 @@ void KbStateApplet::toggleAccessX() {
 	updateMenu();
 	layout();
 	updateGeometry();
-	saveConfig();
 	emit updateLayout();
 }
 
 void KbStateApplet::configureAccessX() {
-   kapp->startServiceByDesktopName("kcmaccess");
+   KToolInvocation::startServiceByDesktopName("kcmaccess");
 }
 
 void KbStateApplet::configureKeyboard() {
    // The modulename "keyboard" is ambiguous on SuSE systems
    // as there is also a YaST-module called "keyboard".
-   KProcess proc;
-   proc << "kcmshell";
-   proc << "kde/keyboard";
-   proc.start(KProcess::DontCare);
-   proc.detach();
+   QStringList arg;
+   arg<<"kde/keyboard";
+   QProcess::startDetached("kcmshell4",arg);
 }
 
 void KbStateApplet::configureMouse() {
-   kapp->startServiceByDesktopName("mouse");
+   KToolInvocation::startServiceByDesktopName("mouse");
 }
 
 void KbStateApplet::about() {
-   KAboutData about("kbstateapplet", I18N_NOOP("Keyboard Status Applet"), "0.2",
-                    I18N_NOOP("Panel applet that shows the state of the modifier keys"), KAboutData::License_GPL_V2, "(C) 2004 Gunnar Schmi Dt");
-   KAboutApplication a(&about, this);
+   KAboutData about("kbstateapplet", 0, ki18n("Keyboard Status Applet"), "0.2",
+                    ki18n("Panel applet that shows the state of the modifier keys"), KAboutData::License_GPL_V2, ki18n("(C) 2004 Gunnar Schmi Dt"));
+   KAboutApplicationDialog a(&about, this);
    a.exec();
 }
 
 void KbStateApplet::loadConfig()
 {
-   KConfig *c = config();
-   c->setGroup("General");
-   size = c->readNumEntry("IconDim", 20);
-	fillSpace    = c->readBoolEntry("fill space", true);
-	showModifiers = c->readBoolEntry("Modifierkeys visible",true);
-	showLockkeys  = c->readBoolEntry("Lockkeys visible",true);
-	showMouse    = c->readBoolEntry("Mouse status visible",true);
-	showAccessX  = c->readBoolEntry("Slowkeys status visible",true);
-	showAccessX  = c->readBoolEntry("AccessX status visible",showAccessX);
+   KConfigGroup c(config(), "General");
+   size = c.readEntry("IconDim", 20);
+	fillSpace    = c.readEntry("fill space", true);
+	showModifiers = c.readEntry("Modifierkeys visible", true);
+	showLockkeys  = c.readEntry("Lockkeys visible", true);
+	showMouse    = c.readEntry("Mouse status visible", true);
+	showAccessX  = c.readEntry("Slowkeys status visible", true);
+	showAccessX  = c.readEntry("AccessX status visible", showAccessX);
 }
 
 void KbStateApplet::saveConfig()
 {
-   KConfig *c = config();
-   c->setGroup("General");
-	c->writeEntry("IconDim", size);
-	c->writeEntry("fill space", fillSpace);
-   c->writeEntry("Modifierkeys visible",    showModifiers);
-   c->writeEntry("Lockkeys visible",        showLockkeys);
-	c->writeEntry("Mouse status visible",    showMouse);
-	c->writeEntry("AccessX status visible",  showAccessX);
-   c->sync();
+   KConfigGroup c(config(), "General");
+	c.writeEntry("IconDim", size);
+	c.writeEntry("fill space", fillSpace);
+   c.writeEntry("Modifierkeys visible",    showModifiers);
+   c.writeEntry("Lockkeys visible",        showLockkeys);
+	c.writeEntry("Mouse status visible",    showMouse);
+	c.writeEntry("AccessX status visible",  showAccessX);
+   c.sync();
 }
 
 /********************************************************************/
 
-KeyIcon::KeyIcon (int keyId, KInstance *instance,
+KeyIcon::KeyIcon (int keyId, KIconLoader *iconLoader,
                   QWidget *parent, const char *name)
  : StatusIcon (modifierKeys[keyId].name, parent, name) {
-   this->instance = instance;
+   this->iconLoader = iconLoader;
    this->keyId = keyId;
    this->tristate = (modifierKeys[keyId].isModifier);
    isLocked  = false;
@@ -786,17 +789,17 @@ void KeyIcon::resizeEvent( QResizeEvent*e )
 void KeyIcon::updateImages () {
    int size = width()<height() ? width() : height();
 
-   locked    = instance->iconLoader()->loadIcon("lock_overlay", KIcon::Panel, size-4);
+   locked    = iconLoader->loadIcon("lock_overlay", KIconLoader::Panel, size-4);
 	if (strcmp(modifierKeys[keyId].icon, "")) {
-	   latched   = instance->iconLoader()->loadIcon(modifierKeys[keyId].icon, KIcon::NoGroup, size-4);
-   	unlatched = instance->iconLoader()->loadIcon(modifierKeys[keyId].icon, KIcon::NoGroup, size-4);
+	   latched   = iconLoader->loadIcon(modifierKeys[keyId].icon, KIconLoader::NoGroup, size-4);
+   	unlatched = iconLoader->loadIcon(modifierKeys[keyId].icon, KIconLoader::NoGroup, size-4);
 		
 		QImage img = latched.convertToImage();
-		KIconEffect::colorize(img,  KGlobalSettings::highlightedTextColor(), 1.0);
+		KIconEffect::colorize(img,  KColorScheme(QPalette::Active, KColorScheme::Selection).foreground().color(), 1.0);
 		latched.convertFromImage (img);
 		
 		img = unlatched.convertToImage();
-		KIconEffect::colorize(img, KGlobalSettings::textColor(), 1.0);
+		KIconEffect::colorize(img, KColorScheme(QPalette::Active, KColorScheme::View).foreground().color(), 1.0);
 		unlatched.convertFromImage (img);
 	}
 
@@ -811,17 +814,17 @@ void KeyIcon::drawButton (QPainter *p) {
    int o = 0;
    if (isLocked || isLatched) {
       qDrawShadePanel (p, 0, 0, width(), height(), colorGroup(), true, 1, NULL);
-      p->fillRect (1,1,width()-2,height()-2, KGlobalSettings::highlightColor());
+      p->fillRect (1,1,width()-2,height()-2, KColorScheme(QPalette::Active, KColorScheme::Selection).background().color());
 		if (strcmp(modifierKeys[keyId].icon, ""))
 			p->drawPixmap (x+1,y+1, latched);
-      black = KGlobalSettings::highlightedTextColor();
+      black = KColorScheme(QPalette::Active, KColorScheme::Selection).foreground().color();
       o = 1;
    }
    else {
       qDrawShadePanel (p, 0, 0, width(), height(), colorGroup(), false, 1, NULL);
 		if (strcmp(modifierKeys[keyId].icon, ""))
 			p->drawPixmap (x,y, unlatched);
-      black = KGlobalSettings::textColor();
+      black = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
    }
 
    QString text = i18n(modifierKeys[keyId].text);
@@ -855,10 +858,10 @@ void KeyIcon::drawButton (QPainter *p) {
 
 /********************************************************************/
 
-MouseIcon::MouseIcon (KInstance *instance, QWidget *parent, const char *name)
+MouseIcon::MouseIcon (KIconLoader *iconLoader, QWidget *parent, const char *name)
 	: StatusIcon ("", parent, name)
 {
-	this->instance = instance;
+	this->iconLoader = iconLoader;
 	state = 0;
 	activekey = 0;
 	updateImages ();
@@ -886,9 +889,8 @@ void MouseIcon::resizeEvent( QResizeEvent*e )
 	updateImages();
 }
 
-QPixmap loadIcon(KInstance *instance, int size, QColor color, QString name) {
-	KIconLoader *loader = instance->iconLoader();
-	QPixmap result = loader->loadIcon(name, KIcon::NoGroup, size);
+QPixmap loadIcon(KIconLoader *iconLoader, int size, const QColor &color, const QString &name) {
+	QPixmap result = iconLoader->loadIcon(name, KIconLoader::NoGroup, size);
 
 	QImage img = result.convertToImage();
 	KIconEffect::colorize(img, color, 1.0);
@@ -900,23 +902,23 @@ QPixmap loadIcon(KInstance *instance, int size, QColor color, QString name) {
 void MouseIcon::updateImages () {
 	int size = width()<height() ? width() : height();
 
-	QColor textcolor = KGlobalSettings::textColor();
-	QColor basecolor = KGlobalSettings::baseColor();
-	mouse = loadIcon (instance, size, textcolor, "kbstate_mouse");
-	leftSelected   = loadIcon (instance, size, textcolor,
+	QColor textcolor = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
+	QColor basecolor = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
+	mouse = loadIcon (iconLoader, size, textcolor, "kbstate_mouse");
+	leftSelected   = loadIcon (iconLoader, size, textcolor,
 										"kbstate_mouse_left_selected");
-	middleSelected = loadIcon (instance, size, textcolor,
+	middleSelected = loadIcon (iconLoader, size, textcolor,
 										"kbstate_mouse_mid_selected");
-	rightSelected  = loadIcon (instance, size, textcolor,
+	rightSelected  = loadIcon (iconLoader, size, textcolor,
 										"kbstate_mouse_right_selected");
-	leftDot   = loadIcon (instance, size, textcolor, "kbstate_mouse_left");
-	middleDot = loadIcon (instance, size, textcolor, "kbstate_mouse_mid");
-	rightDot  = loadIcon (instance, size, textcolor, "kbstate_mouse_right");
-	leftDotSelected   = loadIcon (instance, size, basecolor,
+	leftDot   = loadIcon (iconLoader, size, textcolor, "kbstate_mouse_left");
+	middleDot = loadIcon (iconLoader, size, textcolor, "kbstate_mouse_mid");
+	rightDot  = loadIcon (iconLoader, size, textcolor, "kbstate_mouse_right");
+	leftDotSelected   = loadIcon (iconLoader, size, basecolor,
 											"kbstate_mouse_left");
-	middleDotSelected = loadIcon (instance, size, basecolor,
+	middleDotSelected = loadIcon (iconLoader, size, basecolor,
 											"kbstate_mouse_mid");
-	rightDotSelected  = loadIcon (instance, size, basecolor,
+	rightDotSelected  = loadIcon (iconLoader, size, basecolor,
 											"kbstate_mouse_right");
 
 	update();
@@ -956,11 +958,11 @@ void MouseIcon::drawButton (QPainter *p) {
 
 /********************************************************************/
 
-TimeoutIcon::TimeoutIcon (KInstance *instance, const QString &text,
+TimeoutIcon::TimeoutIcon (KIconLoader *iconLoader, const QString &text,
 								  const QString &featurename,
 								  QWidget *parent, const char *name)
  : StatusIcon (text, parent, name) {
-	this->instance = instance;
+	this->iconLoader = iconLoader;
 	this->featurename = featurename;
 	glyth = " ";
 	setImage (featurename);
@@ -973,10 +975,10 @@ TimeoutIcon::~TimeoutIcon () {
 void TimeoutIcon::update () {
    int size = width()<height() ? width() : height();
    if (pixmap.width() != size)
-		pixmap = instance->iconLoader()->loadIcon(iconname, KIcon::NoGroup, size);
+		pixmap = iconLoader->loadIcon(iconname, KIconLoader::NoGroup, size);
 
    QImage img = pixmap.convertToImage();
-   KIconEffect::colorize(img, KGlobalSettings::textColor(), 1.0);
+   KIconEffect::colorize(img, KColorScheme(QPalette::Active, KColorScheme::View).foreground().color(), 1.0);
    pixmap.convertFromImage (img);
 
    image = pixmap;
@@ -988,7 +990,7 @@ void TimeoutIcon::setGlyth (const QString &glyth) {
    this->glyth = glyth;
 
    QImage img = pixmap.convertToImage();
-   KIconEffect::colorize(img, KGlobalSettings::textColor(), 1.0);
+   KIconEffect::colorize(img, KColorScheme(QPalette::Active, KColorScheme::View).foreground().color(), 1.0);
    pixmap.convertFromImage (img);
 
    image = pixmap;
@@ -1000,10 +1002,10 @@ void TimeoutIcon::setImage (const QString &name, int timeout) {
    iconname = name;
 	if (!name.isNull() && !name.isEmpty()) {
 	   int size = width()<height() ? width() : height();
-		pixmap = instance->iconLoader()->loadIcon(iconname, KIcon::NoGroup, size);
+		pixmap = iconLoader->loadIcon(iconname, KIconLoader::NoGroup, size);
 
    	QImage img = pixmap.convertToImage();
-   	KIconEffect::colorize(img, KGlobalSettings::textColor(), 1.0);
+   	KIconEffect::colorize(img, KColorScheme(QPalette::Active, KColorScheme::View).foreground().color(), 1.0);
    	pixmap.convertFromImage (img);
 
    	image = pixmap;
@@ -1027,7 +1029,7 @@ void TimeoutIcon::drawButton (QPainter *p) {
 	if (!iconname.isNull() && !iconname.isEmpty())
 	   p->drawPixmap(0,0, image);
 	else if (glyth == " ") {
-		text = i18n("a (the first letter in the alphabet)", "a");
+		text = i18nc("a (the first letter in the alphabet)", "a");
 		count = 3;
 		factor = 64;
 	}
@@ -1045,12 +1047,12 @@ void TimeoutIcon::drawButton (QPainter *p) {
 
    p->setFont (font);
 	if (count == 1) {
-		p->setPen (KGlobalSettings::textColor());
+		p->setPen (KColorScheme(QPalette::Active, KColorScheme::View).foreground().color());
 	   p->drawText (0,0, width()/2, height()/2, Qt::AlignCenter, text);
 	}
 	else {
-		QColor t = KGlobalSettings::textColor();
-		QColor b = KGlobalSettings::baseColor();
+		QColor t = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
+		QColor b = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
 		p->setPen (QColor ((2*t.red()+3*b.red())/5,
 					  (2*t.green()+3*b.green())/5,
 					  (2*t.blue()+3*b.blue())/5));
@@ -1059,7 +1061,7 @@ void TimeoutIcon::drawButton (QPainter *p) {
 					  (2*t.green()+b.green())/3,
 					  (2*t.blue()+b.blue())/3));
 		p->drawText (0,0, width(), height(), Qt::AlignCenter, text);
-		p->setPen (KGlobalSettings::textColor());
+		p->setPen (KColorScheme(QPalette::Active, KColorScheme::View).foreground().color());
 		p->drawText (0,0, width()/2, height(), Qt::AlignCenter, text);
 	}
 }
@@ -1067,7 +1069,8 @@ void TimeoutIcon::drawButton (QPainter *p) {
 /********************************************************************/
 
 StatusIcon::StatusIcon (const QString &text, QWidget *parent, const char *name)
- : QPushButton (text, parent, name) {
+ : QPushButton (text, parent) {
+   setObjectName(name);
    setSizePolicy(QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored));
 }
 
