@@ -15,19 +15,22 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: phraselist.h,v 1.2 2003/03/17 22:57:48 mueller Exp $
-
 #ifndef PHRASELIST_H
 #define PHRASELIST_H
 
 // include files for KDE
-#include <klistbox.h>
+#include <k3listbox.h>
 #include <klineedit.h>
-#include <kprinter.h>
+#include <kconfig.h>
+#include <kcombobox.h>
 
 // include files for Qt
-#include <qwidget.h>
-#include <qpushbutton.h>
+#include <QtGui/QWidget>
+#include <QtGui/QPushButton>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QPrinter>
+
+class WordCompletion;
 
 /**
  * This class represents a phrase list. It contains methods for manipulating
@@ -45,7 +48,7 @@ public:
    ~PhraseList();
    
    /** contains the implementation for printing functionality */
-   void print(KPrinter *pPrinter);
+   void print(QPrinter *pPrinter);
 
    QStringList getListSelection();
    
@@ -72,23 +75,31 @@ public slots:
 
    void save ();
    void open ();
-   void open (KURL url);
+   void open (KUrl url);
    
    void selectAllEntries ();
    void deselectAllEntries ();
 
+   void configureCompletion();
+   void saveWordCompletion();
+   void saveCompletionOptions(KConfig *config);
+   void readCompletionOptions(KConfig *config);
+
 protected slots:
    void lineEntered (const QString &phrase);
-   void contextMenuRequested (QListBoxItem *, const QPoint &pos);
+   void contextMenuRequested (Q3ListBoxItem *, const QPoint &pos);
    void textChanged (const QString &s);
    void selectionChanged ();
    void keyPressEvent (QKeyEvent *e);
+   void configureCompletionCombo(const QStringList &list);
 
 private:
-   KListBox *listBox;
+   K3ListBox *listBox;
+   KComboBox *dictionaryCombo;
    KLineEdit *lineEdit;
    QPushButton *speakButton;
    QString line;
+   WordCompletion *completion;
   
    bool isInSlot;
    
