@@ -18,15 +18,15 @@
 #include <stdlib.h> 
 
 // QT includes
+#include <QtCore/QByteArray>
 
 // KDE includes
-#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <arts/kartsdispatcher.h>
-#include <dcopclient.h>
+// #include <arts/kartsdispatcher.h>
+// #include <dcopclient.h>
 
 // App specific includes
 #include "version.h"
@@ -40,21 +40,24 @@ static const char *description =
 int main(int argc, char *argv[])
 {
 
-  KAboutData aboutData( "ksayit", I18N_NOOP("KSayIt"),
-    KSAYIT_VERSION, description, KAboutData::License_GPL,
-    "(c) 1996 - 2005, Robert Vogl", 0, 0, "voglrobe@web.de");
-  aboutData.addAuthor("Robert Vogl",0, "voglrobe@web.de");
+  KAboutData aboutData( "ksayit", 0, ki18n("KSayIt"),
+    KSAYIT_VERSION, ki18n(description), KAboutData::License_GPL,
+    ki18n("(c) 1996 - 2005, Robert Vogl"), KLocalizedString(), 0, "voglrobe@web.de");
+  aboutData.addAuthor(ki18n("Robert Vogl"),KLocalizedString(), "voglrobe@web.de");
   KCmdLineArgs::init( argc, argv, &aboutData );
 
   KApplication app;
 
     // setup MCOP
-    KArtsDispatcher dispatcher;
+    // TODO: aRts no longer supported.  Either eliminate audio
+    // effects or port to Phonon.
+    // KArtsDispatcher dispatcher;
  
     // setup DCOP
-    QCString appID = app.dcopClient()->registerAs( app.name(), false );
+    // TODO: port to DBUS.
+    // DCOPCString appID = app.dcopClient()->registerAs( app.name(), false );
     
-    KSayItApp *ksayit = new KSayItApp(0, "MainWindow", 0, appID);    
+    KSayItApp *ksayit = new KSayItApp(0, "MainWindow", 0, 0 /*appID*/);
     // ksayit->hide();
     ksayit->show();
     
