@@ -22,15 +22,17 @@
  ******************************************************************************/
 
 // Qt includes.
-#include <qfile.h>
-#include <qregexp.h>
+#include <QtCore/QFile>
+#include <QtCore/QRegExp>
+#include <QtCore/QTextStream>
 
 // KDE includes.
 #include <kdeversion.h>
 #include <kconfig.h>
-#include <ktempfile.h>
+#include <kconfiggroup.h>
+#include <ktemporaryfile.h>
 #include <kstandarddirs.h>
-#include <kprocess.h>
+#include <k3process.h>
 #include <kdebug.h>
 
 // KTTS includes.
@@ -44,8 +46,8 @@
 /**
  * Constructor.
  */
-XmlTransformerProc::XmlTransformerProc( QObject *parent, const char *name, const QStringList& ) :
-    KttsFilterProc(parent, name)
+XmlTransformerProc::XmlTransformerProc( QObject *parent, const QStringList& ) :
+    KttsFilterProc(parent)
 {
     m_xsltProc = 0;
 }
@@ -69,18 +71,18 @@ XmlTransformerProc::XmlTransformerProc( QObject *parent, const char *name, const
  * Note: The parameters are for reading from kttsdrc file.  Plugins may wish to maintain
  * separate configuration files of their own.
  */
-bool XmlTransformerProc::init(KConfig* config, const QString& configGroup)
+bool XmlTransformerProc::init(KConfig* c, const QString& configGroup)
 {
-    // kdDebug() << "XmlTransformerProc::init: Running." << endl;
-    config->setGroup( configGroup );
-    m_UserFilterName = config->readEntry( "UserFilterName" );
-    m_xsltFilePath = config->readEntry( "XsltFilePath" );
-    m_xsltprocPath = config->readEntry( "XsltprocPath" );
-    m_rootElementList = config->readListEntry( "RootElement", ',' );
-    m_doctypeList = config->readListEntry( "DocType", ',' );
-    m_appIdList = config->readListEntry( "AppID", ',' );
-    kdDebug() << "XmlTransformerProc::init: m_xsltprocPath = " << m_xsltprocPath << endl;
-    kdDebug() << "XmlTransformerProc::init: m_xsltFilePath = " << m_xsltFilePath << endl;
+    // kDebug() << "XmlTransformerProc::init: Running.";
+    KConfigGroup config( c, configGroup );
+    m_UserFilterName = config.readEntry( "UserFilterName" );
+    m_xsltFilePath = config.readEntry( "XsltFilePath" );
+    m_xsltprocPath = config.readEntry( "XsltprocPath" );
+    m_rootElementList = config.readEntry( "RootElement", QStringList() );
+    m_doctypeList = config.readEntry( "DocType", QStringList() );
+    m_appIdList = config.readEntry( "AppID", QStringList() );
+    kDebug() << "XmlTransformerProc::init: m_xsltprocPath = " << m_xsltprocPath;
+    kDebug() << "XmlTransformerProc::init: m_xsltFilePath = " << m_xsltFilePath;
     return ( m_xsltFilePath.isEmpty() || m_xsltprocPath.isEmpty() );
 }
 
@@ -106,13 +108,13 @@ bool XmlTransformerProc::init(KConfig* config, const QString& configGroup)
  *                          Also useful for hints about how to do the filtering.
  */
 /*virtual*/ QString XmlTransformerProc::convert(const QString& inputText, TalkerCode* talkerCode,
-    const QCString& appId)
+    const QString& appId)
 {
-    // kdDebug() << "XmlTransformerProc::convert: Running." << endl;
+    // kDebug() << "XmlTransformerProc::convert: Running.";
     // If not properly configured, do nothing.
     if ( m_xsltFilePath.isEmpty() || m_xsltprocPath.isEmpty() )
     {
-        kdDebug() << "XmlTransformerProc::convert: not properly configured" << endl;
+        kDebug() << "XmlTransformerProc::convert: not properly configured";
         return inputText;
     }
     // Asynchronously convert and wait for completion.
@@ -140,16 +142,16 @@ bool XmlTransformerProc::init(KConfig* config, const QString& configGroup)
  * program must call @ref ackFinished to acknowledge the conversion.
  */
 /*virtual*/ bool XmlTransformerProc::asyncConvert(const QString& inputText, TalkerCode* /*talkerCode*/,
-    const QCString& appId)
+    const QString& appId)
 {
     m_wasModified = false;
 
-    // kdDebug() << "XmlTransformerProc::asyncConvert: Running." << endl;
+    // kDebug() << "XmlTransformerProc::asyncConvert: Running.";
     m_text = inputText;
     // If not properly configured, do nothing.
     if ( m_xsltFilePath.isEmpty() || m_xsltprocPath.isEmpty() )
     {
-        kdDebug() << "XmlTransformerProc::asyncConvert: not properly configured." << endl;
+        kDebug() << "XmlTransformerProc::asyncConvert: not properly configured.";
         return false;
     }
 
@@ -157,8 +159,8 @@ bool XmlTransformerProc::init(KConfig* config, const QString& configGroup)
     // If not correct XML type, or DOCTYPE, do nothing.
     if ( !m_rootElementList.isEmpty() )
     {
-        // kdDebug() << "XmlTransformerProc::asyncConvert:: searching for root elements " << m_rootElementList << endl;
-        for ( uint ndx=0; ndx < m_rootElementList.count(); ++ndx )
+        // kDebug() << "XmlTransformerProc::asyncConvert:: searching for root elements " << m_rootElementList;
+        for ( int ndx=0; ndx < m_rootElementList.count(); ++ndx )
         {
             if ( KttsUtils::hasRootElement( inputText, m_rootElementList[ndx] ) )
             {
@@ -168,13 +170,13 @@ bool XmlTransformerProc::init(KConfig* config, const QString& configGroup)
         }
         if ( !found && m_doctypeList.isEmpty() )
         {
-            kdDebug() << "XmlTransformerProc::asyncConvert: Did not find root element(s)" << m_rootElementList << endl;
+            kDebug() << "XmlTransformerProc::asyncConvert: Did not find root element(s)" << m_rootElementList;
             return false;
         }
     }
     if ( !found && !m_doctypeList.isEmpty() )
     {
-        for ( uint ndx=0; ndx < m_doctypeList.count(); ++ndx )
+        for ( int ndx=0; ndx < m_doctypeList.count(); ++ndx )
         {
             if ( KttsUtils::hasDoctype( inputText, m_doctypeList[ndx] ) )
             {
@@ -184,7 +186,7 @@ bool XmlTransformerProc::init(KConfig* config, const QString& configGroup)
         }
         if ( !found )
         {
-            // kdDebug() << "XmlTransformerProc::asyncConvert: Did not find doctype(s)" << m_doctypeList << endl;
+            // kDebug() << "XmlTransformerProc::asyncConvert: Did not find doctype(s)" << m_doctypeList;
             return false;
         }
     }
@@ -193,10 +195,10 @@ bool XmlTransformerProc::init(KConfig* config, const QString& configGroup)
     if ( !m_appIdList.isEmpty() )
     {
         QString appIdStr = appId;
-        // kdDebug() << "XmlTransformrProc::convert: converting " << inputText << " if appId "
+        // kDebug() << "XmlTransformrProc::convert: converting " << inputText << " if appId "
         //     << appId << " matches " << m_appIdList << endl;
         found = false;
-        for ( uint ndx=0; ndx < m_appIdList.count(); ++ndx )
+        for ( int ndx=0; ndx < m_appIdList.count(); ++ndx )
         {
             if ( appIdStr.contains(m_appIdList[ndx]) )
             {
@@ -206,60 +208,58 @@ bool XmlTransformerProc::init(KConfig* config, const QString& configGroup)
         }
         if ( !found )
         {
-            // kdDebug() << "XmlTransformerProc::asyncConvert: Did not find appId(s)" << m_appIdList << endl;
+            // kDebug() << "XmlTransformerProc::asyncConvert: Did not find appId(s)" << m_appIdList;
             return false;
         }
     }
 
     /// Write @param text to a temporary file.
-    KTempFile inFile(locateLocal("tmp", "kttsd-"), ".xml");
-    m_inFilename = inFile.file()->name();
-    QTextStream* wstream = inFile.textStream();
-    if (wstream == 0) {
-        /// wtf...
-        kdDebug() << "XmlTransformerProc::convert: Can't write to " << m_inFilename << endl;;
-        return false;
-    }
+    KTemporaryFile inFile;
+    inFile.setPrefix("kttsd-");
+    inFile.setSuffix(".xml");
+    inFile.setAutoRemove(false);
+    inFile.open();
+    m_inFilename = inFile.fileName();
+    QTextStream wstream (&inFile);
     // TODO: Is encoding an issue here?
     // If input does not have xml processing instruction, add it.
-    if (!inputText.startsWith("<?xml")) *wstream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>";
+    if (!inputText.startsWith("<?xml")) wstream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>";
     // FIXME: Temporary Fix until Konqi returns properly formatted xhtml with & coded as &amp;
     // This will change & inside a CDATA section, which is not good, and also within comments and
     // processing instructions, which is OK because we don't speak those anyway.
     QString text = inputText;
     text.replace(QRegExp("&(?!amp;)"),"&amp;");
-    *wstream << text;
-    inFile.close();
-#if KDE_VERSION >= KDE_MAKE_VERSION (3,3,0)
-    inFile.sync();
-#endif
+    wstream << text;
+    inFile.flush();
 
     // Get a temporary output file name.
-    KTempFile outFile(locateLocal("tmp", "kttsd-"), ".output");
-    m_outFilename = outFile.file()->name();
-    outFile.close();
-    // outFile.unlink();    // only activate this if necessary.
+    KTemporaryFile outFile;
+    outFile.setPrefix("kttsd-");
+    outFile.setSuffix(".output");
+    outFile.setAutoRemove(false);
+    outFile.open();
+    m_outFilename = outFile.fileName();
 
     /// Spawn an xsltproc process to apply our stylesheet to input file.
-    m_xsltProc = new KProcess;
+    m_xsltProc = new K3Process;
     *m_xsltProc << m_xsltprocPath;
     *m_xsltProc << "-o" << m_outFilename  << "--novalid"
             << m_xsltFilePath << m_inFilename;
     // Warning: This won't compile under KDE 3.2.  See FreeTTS::argsToStringList().
-    // kdDebug() << "SSMLConvert::transform: executing command: " <<
+    // kDebug() << "SSMLConvert::transform: executing command: " <<
     //     m_xsltProc->args() << endl;
 
     m_state = fsFiltering;
-    connect(m_xsltProc, SIGNAL(processExited(KProcess*)),
-            this, SLOT(slotProcessExited(KProcess*)));
-    connect(m_xsltProc, SIGNAL(receivedStdout(KProcess*, char*, int)),
-            this, SLOT(slotReceivedStdout(KProcess*, char*, int)));
-    connect(m_xsltProc, SIGNAL(receivedStderr(KProcess*, char*, int)),
-            this, SLOT(slotReceivedStderr(KProcess*, char*, int)));
-    if (!m_xsltProc->start(KProcess::NotifyOnExit,
-         static_cast<KProcess::Communication>(KProcess::Stdout | KProcess::Stderr)))
+    connect(m_xsltProc, SIGNAL(processExited(K3Process*)),
+            this, SLOT(slotProcessExited(K3Process*)));
+    connect(m_xsltProc, SIGNAL(receivedStdout(K3Process*, char*, int)),
+            this, SLOT(slotReceivedStdout(K3Process*, char*, int)));
+    connect(m_xsltProc, SIGNAL(receivedStderr(K3Process*, char*, int)),
+            this, SLOT(slotReceivedStderr(K3Process*, char*, int)));
+    if (!m_xsltProc->start(K3Process::NotifyOnExit,
+         static_cast<K3Process::Communication>(K3Process::Stdout | K3Process::Stderr)))
     {
-        kdDebug() << "XmlTransformerProc::convert: Error starting xsltproc" << endl;
+        kDebug() << "XmlTransformerProc::convert: Error starting xsltproc";
         m_state = fsIdle;
         return false;
     }
@@ -275,14 +275,14 @@ void XmlTransformerProc::processOutput()
     if (m_xsltProc->normalExit())
         exitStatus = m_xsltProc->exitStatus();
     else
-        kdDebug() << "XmlTransformerProc::processOutput: xsltproc was killed." << endl;
+        kDebug() << "XmlTransformerProc::processOutput: xsltproc was killed.";
 
     delete m_xsltProc;
     m_xsltProc = 0;
 
     if (exitStatus != 0)
     {
-        kdDebug() << "XmlTransformerProc::processOutput: xsltproc abnormal exit.  Status = " << exitStatus << endl;
+        kDebug() << "XmlTransformerProc::processOutput: xsltproc abnormal exit.  Status = " << exitStatus;
         m_state = fsFinished;
         QFile::remove(m_outFilename);
         emit filteringFinished();
@@ -291,17 +291,17 @@ void XmlTransformerProc::processOutput()
 
     /// Read back the data that was written to /tmp/fileName.output.
     QFile readfile(m_outFilename);
-    if(!readfile.open(IO_ReadOnly)) {
+    if(!readfile.open(QIODevice::ReadOnly)) {
         /// uhh yeah... Issues writing to the output file.
-        kdDebug() << "XmlTransformerProc::processOutput: Could not read file " << m_outFilename << endl;
+        kDebug() << "XmlTransformerProc::processOutput: Could not read file " << m_outFilename;
         m_state = fsFinished;
         emit filteringFinished();
     }
     QTextStream rstream(&readfile);
-    m_text = rstream.read();
+    m_text = rstream.readAll();
     readfile.close();
 
-    kdDebug() << "XmlTransformerProc::processOutput: Read file at " + m_inFilename + " and created " + m_outFilename + " based on the stylesheet at " << m_xsltFilePath << endl;
+    kDebug() << "XmlTransformerProc::processOutput: Read file at " + m_inFilename + " and created " + m_outFilename + " based on the stylesheet at " << m_xsltFilePath;
 
     // Clean up.
     QFile::remove(m_outFilename);
@@ -323,7 +323,7 @@ void XmlTransformerProc::processOutput()
             if ( !m_xsltProc->wait( 15 ) )
             {
                 m_xsltProc->kill();
-                kdDebug() << "XmlTransformerProc::waitForFinished: After waiting 15 seconds, xsltproc process seems to hung.  Killing it." << endl;
+                kDebug() << "XmlTransformerProc::waitForFinished: After waiting 15 seconds, xsltproc process seems to hung.  Killing it.";
                 processOutput();
             }
         }
@@ -346,7 +346,7 @@ void XmlTransformerProc::processOutput()
 /*virtual*/ void XmlTransformerProc::ackFinished()
 {
     m_state = fsIdle;
-    m_text = QString::null;
+    m_text.clear();
 }
 
 /**
@@ -365,21 +365,21 @@ void XmlTransformerProc::processOutput()
  */
 /*virtual*/ bool XmlTransformerProc::wasModified() { return m_wasModified; }
 
-void XmlTransformerProc::slotProcessExited(KProcess*)
+void XmlTransformerProc::slotProcessExited(K3Process*)
 {
-    // kdDebug() << "XmlTransformerProc::slotProcessExited: xsltproc has exited." << endl;
+    // kDebug() << "XmlTransformerProc::slotProcessExited: xsltproc has exited.";
     processOutput();
 }
 
-void XmlTransformerProc::slotReceivedStdout(KProcess*, char* /*buffer*/, int /*buflen*/)
+void XmlTransformerProc::slotReceivedStdout(K3Process*, char* /*buffer*/, int /*buflen*/)
 {
     // QString buf = QString::fromLatin1(buffer, buflen);
-    // kdDebug() << "XmlTransformerProc::slotReceivedStdout: Received from xsltproc: " << buf << endl;
+    // kDebug() << "XmlTransformerProc::slotReceivedStdout: Received from xsltproc: " << buf;
 }
 
-void XmlTransformerProc::slotReceivedStderr(KProcess*, char* buffer, int buflen)
+void XmlTransformerProc::slotReceivedStderr(K3Process*, char* buffer, int buflen)
 {
     QString buf = QString::fromLatin1(buffer, buflen);
-    kdDebug() << "XmlTransformerProc::slotReceivedStderr: Received error from xsltproc: " << buf << endl;
+    kDebug() << "XmlTransformerProc::slotReceivedStderr: Received error from xsltproc: " << buf;
 }
 
