@@ -29,16 +29,14 @@
 #include <sys/poll.h>
 
 // Qt includes.
-#include <qstring.h>
-#include <qobject.h>
-#include <qthread.h>
-#include <qfile.h>
-#include <qmutex.h>
+#include <QtCore/QObject>
+#include <QtCore/QThread>
+#include <QtCore/QFile>
+#include <QtCore/QMutex>
+#include <QtCore/QByteArray>
 
 // KDE includes.
-#include <config.h>
 #include <kdemacros.h>
-#include "kdeexportfix.h"
 #include <kurl.h>
 
 // AlsaPlayer includes.
@@ -58,38 +56,31 @@
 #define FORMAT_WAVE		2
 #define FORMAT_AU		3
 
-static snd_pcm_sframes_t (*readi_func)(snd_pcm_t *handle, void *buffer, snd_pcm_uframes_t size);
-static snd_pcm_sframes_t (*writei_func)(snd_pcm_t *handle, const void *buffer, snd_pcm_uframes_t size);
-static snd_pcm_sframes_t (*readn_func)(snd_pcm_t *handle, void **bufs, snd_pcm_uframes_t size);
-static snd_pcm_sframes_t (*writen_func)(snd_pcm_t *handle, void **bufs, snd_pcm_uframes_t size);
-
-class KDE_EXPORT AlsaPlayer : public Player, QThread
+class AlsaPlayerThread : private QThread
 {
-    Q_OBJECT
-
 public:
-    AlsaPlayer(QObject* parent = 0, const char* name = 0, const QStringList& args=QStringList());
-    ~AlsaPlayer();
+    AlsaPlayerThread(QObject* parent = 0);
+    ~AlsaPlayerThread();
 
-    virtual void startPlay(const QString& file);
-    virtual void pause();
-    virtual void stop();
+    void startPlay(const QString& file);
+    void pause();
+    void stop();
 
-    virtual void setVolume(float volume = 1.0);
-    virtual float volume() const;
+    void setVolume(float volume = 1.0);
+    float volume() const;
 
-    virtual bool playing() const;
-    virtual bool paused() const;
+    bool playing() const;
+    bool paused() const;
 
-    virtual int totalTime() const;
-    virtual int currentTime() const;
-    virtual int position() const; // in this case not really the percent
+    int totalTime() const;
+    int currentTime() const;
+    int position() const; // in this case not really the percent
 
-    virtual void seek(int seekTime);
-    virtual void seekPosition(int position);
+    void seek(int seekTime);
+    void seekPosition(int position);
 
-    virtual QStringList getPluginList( const QCString& classname );
-    virtual void setSinkName(const QString &sinkName);
+    QStringList getPluginList( const QByteArray& classname );
+    void setSinkName(const QString &sinkName);
 
     virtual void setDebugLevel(uint level) { m_debugLevel = level; }
     virtual void setPeriodSize(uint periodSize) { m_defPeriodSize = periodSize; }
@@ -98,8 +89,6 @@ public:
 protected:
     virtual void run();
 
-private slots:
-
 private:
     void init();
     void cleanup();
@@ -110,7 +99,7 @@ private:
 
     ssize_t safe_read(int fd, void *buf, size_t count);
     int test_vocfile(void *buffer);
-    size_t test_wavefile_read(int fd, char *buffer, size_t *size, size_t reqsize, int line);
+    ssize_t test_wavefile_read(int fd, char *buffer, size_t *size, size_t reqsize, int line);
     ssize_t test_wavefile(int fd, char *_buffer, size_t size);
     int test_au(int fd, char *buffer);
     void set_params(void);
@@ -128,7 +117,7 @@ private:
     void playback_go(int fd, size_t loaded, off64_t count, int rtype, const char *name);
     void playback(int fd);
 
-    KURL m_currentURL;
+    KUrl m_currentURL;
     float m_currentVolume;
     QString m_pcmName;
     char* pcm_name;
@@ -136,6 +125,7 @@ private:
 
     QFile audiofile;
     QString name;
+    char* audiofile_name;
     bool canPause;
 
     snd_pcm_t *handle;
@@ -182,6 +172,42 @@ private:
     bool m_simulatedPause;
 };
 
+
+class KDE_EXPORT AlsaPlayer : public Player
+{
+    Q_OBJECT
+public:
+    explicit AlsaPlayer(QObject* parent = 0, const QStringList& args=QStringList());
+    ~AlsaPlayer();
+
+    virtual void startPlay(const QString& file);
+    virtual void pause();
+    virtual void stop();
+
+    virtual void setVolume(float volume = 1.0);
+    virtual float volume() const;
+
+    virtual bool playing() const;
+    virtual bool paused() const;
+
+    virtual int totalTime() const;
+    virtual int currentTime() const;
+    virtual int position() const; // in this case not really the percent
+
+    virtual void seek(int seekTime);
+    virtual void seekPosition(int position);
+
+    virtual QStringList getPluginList( const QByteArray& classname );
+    virtual void setSinkName(const QString &sinkName);
+
+    virtual void setDebugLevel(uint level) { m_AlsaPlayerThread->setDebugLevel(level); }
+    virtual void setPeriodSize(uint periodSize) { m_AlsaPlayerThread->setPeriodSize(periodSize); }
+    virtual void setPeriods(uint periods) { m_AlsaPlayerThread->setPeriods(periods); }
+
+private:
+    AlsaPlayerThread* m_AlsaPlayerThread;
+};
+
 #endif              // ALSAPLAYER_H
 
 // vim: sw=4 ts=8 et
